#AUTHORS:  Skorka P., Grzywacz B., Moron D., Lenda M.
#TITLE: "COVID-19 in memes: The adaptive response of societies to the pandemic?"

# SET YOUR OWN FOLDER WITH ALL DATA ATTACHED TO THE PAPER
setwd("~/Archiwum_May_2020/Dokumenty/Maszynopisy/IJERPH/supplemental")

#required packages
library("apaTables")
library("gsl")
library("broom.mixed")
library("DescTools")
library("dplyr")
library("e1071")
library("ggeffects")
library("ggplot2")
library("ggrepel")
library("gvlma")
library("janeaustenr")
library("qgraph")
library("Hmisc")
library("lme4")
library("lmerTest")
library("multcompView")
library("RColorBrewer")
library("pbkrtest")
library("performance")
library("psych")
library("qqplotr")
library("questionr")
library("rcompanion")
library("readxl")
library("reshape2")
library("scales")
library("see")
library("sjstats")
library("SnowballC")
library("stringdist")
library("stringr")
library("tidymodels")
library("tidyr")
library("tidytext")
library("tm")
library("wordcloud")
library("devtools")


### --- ANALYSES COUNTRY LEVEL -----------

# reading data by country

data <- read_excel("memes_country_data.xlsx", 
                   sheet = "Data_by_country")
data$Tot_dea1M_pop <- as.numeric(data$Tot_dea1M_pop)
data$T_cas1M_pop <- as.numeric(data$T_cas1M_pop)
data$Tot_cases <- as.numeric(data$Tot_cases)
data$Tot_deaths <- as.numeric(data$Tot_deaths)
str(data)
# Subset for "Coronavirus meme"
selected <-  data%>%
  filter(Coronavirus_meme > 0)
str(selected)
#Subset for "Covid-19 meme"
selected1 <-  data%>%
  filter(Covid19_meme > 0)
str(selected)

#Subset for "Covid meme"
selected2 <-  data%>%
  filter(Covid_meme > 0)

####----- INTEREST IN CORONAVIRUS MEME--------------


#skewness: number of deaths due to Covid19 per 1M
hist(data$Tot_dea1M_pop)
skewness(data$Tot_dea1M_pop, na.rm = T)
skewness(log10(data$Tot_dea1M_pop), na.rm = T)
hist(log10(data$Tot_dea1M_pop))

#skewness: number of Covid19 cases per 1M
hist(data$T_cas1M_pop)
skewness(data$T_cas1M_pop, na.rm = T)
skewness(log10(data$T_cas1M_pop), na.rm = T)
hist(log10(data$T_cas1M_pop))

# skewness: number of internet users
hist(data$Internet_users)
skewness(data$Internet_users, na.rm = T)
skewness(log10(data$Internet_users), na.rm = T)
hist(log10(data$Internet_users))

# skewness: interest in coronavirus memes

hist(selected$Coronavirus_meme)
skewness(selected$Coronavirus_meme, na.rm = T)
skewness(log10(selected$Coronavirus_meme), na.rm = T)
hist(log10(selected$Coronavirus_meme))



#linear model


lm_deaths <- lm(log10(Coronavirus_meme)~ log10(Tot_dea1M_pop)+log10(Internet_users), data =selected)
summary((lm_deaths))
summary(aov(lm_deaths))
apa.reg.table(lm_deaths, filename = "LMM_2_APA.doc", table.number = 2)


confint(lm_deaths)

tiff(compression = "lzw",width = 18, height = 22, units = "cm", res = 600)
check_model(lm_deaths)
dev.off()

performance(lm_deaths)
performance_accuracy(lm_deaths, method = "boot", k = 60, n = 1000)
check_collinearity(lm_deaths)
performance_mse(lm_deaths)
check_outliers(lm_deaths)
check_normality(lm_deaths)
gvlma(lm_deaths)

# graph of total deathes versus realtive interest
fig1 <- ggplot(selected, aes(x = Tot_dea1M_pop, y = Coronavirus_meme))+
  theme_bw()+
  geom_point(size = 4, shape = 19, alpha = 0.4)+
  geom_smooth(method = "lm",fill = "#bf987d",
              col = "#98623c")+
  scale_x_log10(labels = function(x) format(x, scientific = FALSE))+
  scale_y_log10()+
  theme(axis.text = element_text(color = "black", size = 14),
        axis.title =element_text(color = "black", size = 14))+
  labs(x = "Total deaths per million", y ="Relative interest in the coronavirus memes")
fig1

ggsave(fig1, filename = "fig1.tiff", width = 14, height = 12, units = "cm", dpi = 600)



#linear model
lm_cases <- lm(log10(Coronavirus_meme)~ log10(T_cas1M_pop)+log10(Internet_users), data =selected)
summary((lm_cases))
summary(aov(lm_cases))
confint(lm_cases)
check_model(lm_cases)

tiff(compression = "lzw",width = 18, height = 22, units = "cm", res = 600)
check_model(lm_cases)
dev.off()

performance(lm_cases)
performance_accuracy(lm_cases, method = "boot", k = 60, n = 1000)
check_collinearity(lm_cases)
performance_mse(lm_cases)
check_outliers(lm_cases)
check_normality(lm_cases)
gvlma(lm_cases)

# graph of total cases versus realtive interest
fig2 <- ggplot(selected, aes(x = T_cas1M_pop, y = Coronavirus_meme))+
  theme_bw()+
  geom_point(size = 4, shape = 19, alpha = 0.4)+
  geom_smooth(method = "lm",fill = "#bf987d",
              col = "#98623c")+
  scale_x_log10(labels = function(x) format(x, scientific = FALSE))+
  scale_y_log10()+
  theme(axis.text = element_text(color = "black", size = 14),
        axis.title =element_text(color = "black", size = 14))+
  labs(x = "Total cases per million", y ="Relative interest in the coronavirus memes")
fig2
ggsave(fig2, filename = "fig2.tiff", width = 14, height = 12, units = "cm", dpi = 600)


# probability deaths vs interest
glm_deaths <- glm(Coronavirus_meme_occurr~ log10(Tot_dea1M_pop)+log10(Internet_users),
                  family = "binomial", data =data)
summary(glm_deaths)
summary(aov(glm_deaths))
confint(glm_deaths)
odds.ratio(glm_deaths)
PseudoR2(glm_deaths)
binned_residuals(glm_deaths)
performance_hosmer(glm_deaths)
check_model(glm_deaths)

tiff(compression = "lzw",width = 18, height = 15, units = "cm", res = 600)
check_model(glm_deaths)
dev.off()

performance(glm_deaths)
performance_accuracy(glm_deaths, method = "boot", k = 60, n = 1000)
check_collinearity(glm_deaths)
performance_mse(glm_deaths)
check_outliers(glm_deaths)
check_normality(glm_deaths)




# graph of probability of interest versus total deathes 
fig3 <- ggplot(data, aes(x = Tot_dea1M_pop, y = Coronavirus_meme_occurr))+
  theme_bw()+
  geom_point(size = 4, shape = 19, alpha = 0.3)+
  scale_x_log10(labels = function(x) format(x, scientific = FALSE))+
  geom_smooth(method = 'glm', fill = "#bf987d",
              col = "#98623c", method.args = list(family = "binomial"))+
  labs(x = "Total deaths per million", y ="Probability of interest in the coronavirus memes")+
  theme(axis.text = element_text(color = "black", size = 14),
        axis.title =element_text(color = "black", size = 14))
fig3 
ggsave(fig3, filename = "fig3.tiff", width = 14, height = 12, units = "cm", dpi = 600)



# logistic regression model of probability of interest versus total cases
glm_cases <- glm(Coronavirus_meme_occurr~ log10(T_cas1M_pop)+log(Internet_users), family = "binomial", data =data)
summary(glm_cases)
summary(aov(glm_cases))
odds.ratio(glm_cases)
PseudoR2(glm_cases)


binned_residuals(glm_cases)
performance_hosmer(glm_cases)
check_model(glm_cases)

tiff(compression = "lzw",width = 18, height = 15, units = "cm", res = 600)
check_model(glm_cases)
dev.off()

performance(glm_cases)
performance_accuracy(glm_cases, method = "boot", k = 60, n = 1000)
check_collinearity(glm_cases)
performance_mse(glm_cases)
check_outliers(glm_cases)
check_normality(glm_cases)



# graph of probability of interest versus total cases

fig4 <- ggplot(data, aes(x = T_cas1M_pop, y = Coronavirus_meme_occurr))+
  theme_bw()+
  geom_point(size = 4, shape = 19, alpha = 0.3)+
  scale_x_log10(labels = function(x) format(x, scientific = FALSE))+
  geom_smooth(method = 'glm', fill = "#bf987d",
              col = "#98623c", method.args = list(family = "binomial"))+
  labs(x = "Total cases per million", y ="Probability of interest in the coronavirus memes")+
  theme(axis.text = element_text(color = "black", size = 14),
        axis.title =element_text(color = "black", size = 14))
fig4 
ggsave(fig4, filename = "fig4.tiff", width = 14, height = 12, units = "cm", dpi = 600)


# Heatmap
correl <- read_excel("memes_country_data.xlsx", sheet = "Graph_corr")
cor_mat <- cor(correl)
cormat <- round(cor(correl),2)
head(cormat)
library(reshape2)
melted_cormat <- melt(cormat)
head(melted_cormat)

get_lower_tri<-function(cormat){
  cormat[upper.tri(cormat)] <- NA
  return(cormat)
}
# Get upper triangle of the correlation matrix
get_upper_tri <- function(cormat){
  cormat[lower.tri(cormat)]<- NA
  return(cormat)
}

upper_tri <- get_upper_tri(cormat)
upper_tri

library(reshape2)
reorder_cormat <- function(cormat){
  # Use correlation between variables as distance
  dd <- as.dist((1-cormat)/2)
  hc <- hclust(dd)
  cormat <-cormat[hc$order, hc$order]
}
melted_cormat <- melt(upper_tri, na.rm = TRUE)



melted_cormat$value1 <-  ifelse(abs(melted_cormat$value) > 0.274, melted_cormat$value, NA)
View(melted_cormat)
cormat <- reorder_cormat(cormat)
# Melt the correlation matrix
melted_cormat <- melt(upper_tri, na.rm = TRUE)
# Create a ggheatmap
ggheatmap <- ggplot(melted_cormat, aes(Var2, Var1, fill = value))+
  geom_tile(color = "white")+
  scale_fill_gradient2(mid="#FBFEF9",low="steelblue",high="#98623c", 
                       midpoint = 0, limit = c(-1,1), space = "Lab", 
                       name="Pearson\nCorrelation") +
  theme_minimal()+ # minimal theme
  theme(axis.text.x = element_text(vjust = 0.5, 
                                   size = 11, hjust = 0.5, color = 'black'),
        axis.text.y = element_text(size = 11, color = 'black'))+
  coord_fixed()
ggheatmap

cor_graph <- ggheatmap +
  geom_text(aes(Var2, Var1, label = value1), color = "#312e2e", size = 4) +
  theme(
    axis.title.x = element_blank(),
    axis.title.y = element_blank(),
    panel.border = element_blank(),
    panel.background = element_blank(),
    axis.ticks = element_blank(),
    legend.justification = c(1, 0),
    legend.position = c(0.9, 0.05),
    legend.direction = "horizontal")+
  guides(fill = guide_colorbar(barwidth = 7, barheight = 1,
                               title.position = "top", title.hjust = 0.5))
cor_graph

ggsave(cor_graph, filename = "heatmap_1C.tiff", width = 14, height = 12, units = "cm", dpi = 600)

### ------------ INTEREST IN COVID19 MEMES ----------------



#linear model
lm_deaths1 <- lm(log10(Covid19_meme)~ log10(Tot_dea1M_pop)+
                   log10(Internet_users), data =selected1)
summary((lm_deaths1))
summary(aov(lm_deaths1))
confint(lm_deaths1)

check_model(lm_deaths1)

tiff(compression = "lzw",width = 19, height = 23, units = "cm", res = 600)
check_model(lm_deaths1)
dev.off()

performance(lm_deaths1)
performance_accuracy(lm_deaths1, method = "boot", k = 60, n = 1000)
check_collinearity(lm_deaths1)
performance_mse(lm_deaths1)
check_outliers(lm_deaths1)
check_normality(lm_deaths1)
gvlma(lm_deaths1)


# graph of total deathes versus realtive interest
fig11 <- ggplot(selected1, aes(x = Tot_dea1M_pop, y = Covid19_meme))+
  theme_bw()+
  geom_point(size = 4, shape = 19, alpha = 0.4)+
  geom_smooth(method = "lm",fill = "#bf987d",
              col = "#98623c")+
  scale_x_log10(labels = function(x) format(x, scientific = FALSE))+
  scale_y_log10()+
  theme(axis.text = element_text(color = "black", size = 14),
        axis.title =element_text(color = "black", size = 14))+
  labs(x = "Total deaths per million", y ="Relative interest in the Covid-19 memes")
fig11

ggsave(fig11, filename = "fig11.tiff", width = 14, height = 12, units = "cm", dpi = 600)



#linear model
lm_cases1 <- lm(log10(Covid19_meme)~ log10(T_cas1M_pop)+log10(Internet_users), data =selected1)
summary((lm_cases1))
summary(aov(lm_cases1))
confint(lm_cases1)
check_model(lm_cases1)

tiff(compression = "lzw",width = 19, height = 22, units = "cm", res = 600)
check_model(lm_cases1)
dev.off()

performance(lm_cases1)
performance_accuracy(lm_cases1, method = "boot", k = 60, n = 1000)
check_collinearity(lm_cases1)
performance_mse(lm_cases1)
check_outliers(lm_cases1)
check_normality(lm_cases1)
gvlma(lm_cases1)



# graph of total cases versus realtive interest
fig22 <- ggplot(selected1, aes(x = T_cas1M_pop, y = Covid19_meme))+
  theme_bw()+
  geom_point(size = 4, shape = 19, alpha = 0.4)+
  geom_smooth(method = "lm",fill = "#bf987d",
              col = "#98623c")+
  scale_x_log10(labels = function(x) format(x, scientific = FALSE))+
  scale_y_log10()+
  theme(axis.text = element_text(color = "black", size = 14),
        axis.title =element_text(color = "black", size = 14))+
  labs(x = "Total cases per million", y ="Relative interest in the Covid-19 memes")
fig22
ggsave(fig22, filename = "fig22.tiff", width = 14, height = 12, units = "cm", dpi = 600)


# probability deaths vs interest
glm_deaths1 <- glm(Covid19_meme_occurr~ log10(Tot_dea1M_pop)+log10(Internet_users),
                  family = "binomial", data =data)
summary(glm_deaths1)
summary(aov(glm_deaths1))
odds.ratio(glm_deaths1)
PseudoR2(glm_deaths1)
check_model(glm_deaths1)

tiff(compression = "lzw",width = 19, height = 16, units = "cm", res = 600)
check_model(glm_deaths1)
dev.off()

performance(glm_deaths1)
performance_accuracy(glm_deaths1, method = "boot", k = 60, n = 1000)
check_collinearity(glm_deaths1)
performance_mse(glm_deaths1)
check_outliers(glm_deaths1)
check_normality(glm_deaths1)


# graph of probability of interest versus total deathes 
fig33 <- ggplot(data, aes(x = Tot_dea1M_pop, y = Covid19_meme_occurr))+
  theme_bw()+
  geom_point(size = 4, shape = 19, alpha = 0.3)+
  scale_x_log10(labels = function(x) format(x, scientific = FALSE))+
  geom_smooth(method = 'glm', fill = "#bf987d",
              col = "#98623c", method.args = list(family = "binomial"))+
  labs(x = "Total deaths per million", y ="Probability of interest in the Covid-19 memes")+
  theme(axis.text = element_text(color = "black", size = 14),
        axis.title =element_text(color = "black", size = 14))
fig33 
ggsave(fig33, filename = "fig33.tiff", width = 14, height = 12, units = "cm", dpi = 600)



# logistic regression model of probability of interest versus total cases
glm_cases1 <- glm(Covid19_meme_occurr~ log10(T_cas1M_pop)+log(Internet_users),
                  family = "binomial", data =data)
summary(glm_cases1)
summary(aov(glm_cases1))
odds.ratio(glm_cases1)
PseudoR2(glm_cases1)
check_model(glm_cases1)

tiff(compression = "lzw",width = 19, height = 16, units = "cm", res = 600)
check_model(glm_cases1)
dev.off()

performance(glm_cases1)
performance_accuracy(glm_cases1, method = "boot", k = 60, n = 1000)
check_collinearity(glm_cases1)
performance_mse(glm_cases1)
check_outliers(glm_cases1)
check_normality(glm_cases1)



# graph of probability of interest versus total cases

fig44 <- ggplot(data, aes(x = T_cas1M_pop, y = Covid19_meme_occurr))+
  theme_bw()+
  geom_point(size = 4, shape = 19, alpha = 0.3)+
  scale_x_log10(labels = function(x) format(x, scientific = FALSE))+
  geom_smooth(method = 'glm', fill = "#bf987d",
              col = "#98623c", method.args = list(family = "binomial"))+
  labs(x = "Total cases per million", y ="Probability of interest in the Covid-19 memes")+
  theme(axis.text = element_text(color = "black", size = 14),
        axis.title =element_text(color = "black", size = 14))
fig44 
ggsave(fig44, filename = "fig44.tiff", width = 14, height = 12, units = "cm", dpi = 600)


### -----------INTEREST IN COVID MEMES ---------------------



#linear model
lm_deaths11 <- lm(log10(Covid_meme)~ log10(Tot_dea1M_pop)+log10(Internet_users), 
                  data =selected2)
summary((lm_deaths11))
summary(aov(lm_deaths11))
confint(lm_deaths11)

check_model(lm_deaths11)

tiff(compression = "lzw",width = 18, height = 22, units = "cm", res = 600)
check_model(lm_deaths11)
dev.off()

performance(lm_deaths11)
performance_accuracy(lm_deaths11, method = "boot", k = 60, n = 1000)
check_collinearity(lm_deaths11)
performance_mse(lm_deaths11)
check_outliers(lm_deaths11)
check_normality(lm_deaths11)
gvlma(lm_deaths11)


# graph of total deathes versus realtive interest
fig111 <- ggplot(selected2, aes(x = Tot_dea1M_pop, y = Covid_meme))+
  theme_bw()+
  geom_point(size = 4, shape = 19, alpha = 0.4)+
  geom_smooth(method = "lm",fill = "#bf987d",
              col = "#98623c")+
  scale_x_log10(labels = function(x) format(x, scientific = FALSE))+
  scale_y_log10()+
  theme(axis.text = element_text(color = "black", size = 14),
        axis.title =element_text(color = "black", size = 14))+
  labs(x = "Total deaths per million", y ="Relative interest in the Covid memes")
fig111

ggsave(fig111, filename = "fig111.tiff", width = 14, height = 12, units = "cm", dpi = 600)



#linear model
lm_cases11 <- lm(log10(Covid_meme)~ log10(T_cas1M_pop)+log10(Internet_users), 
                 data =selected2)
summary((lm_cases11))
summary(aov(lm_cases11))
confint(lm_cases11)

check_model(lm_cases11)

tiff(compression = "lzw",width = 18, height = 22, units = "cm", res = 600)
check_model(lm_cases11)
dev.off()

performance(lm_cases11)
performance_accuracy(lm_cases11, method = "boot", k = 60, n = 1000)
check_collinearity(lm_cases11)
performance_mse(lm_cases11)
check_outliers(lm_cases11)
check_normality(lm_cases11)
gvlma(lm_deaths11)


# graph of total cases versus realtive interest
fig222 <- ggplot(selected2, aes(x = T_cas1M_pop, y = Covid_meme))+
  theme_bw()+
  geom_point(size = 4, shape = 19, alpha = 0.4)+
  geom_smooth(method = "lm",fill = "#bf987d",
              col = "#98623c")+
  scale_x_log10(labels = function(x) format(x, scientific = FALSE))+
  scale_y_log10()+
  theme(axis.text = element_text(color = "black", size = 14),
        axis.title =element_text(color = "black", size = 14))+
  labs(x = "Total cases per million", y ="Relative interest in the Covid memes")
fig222

ggsave(fig222, filename = "fig222.tiff", width = 14, height = 12, units = "cm", dpi = 600)


# probability of interest vs deaths
glm_deaths11 <- glm(Covid_meme_occurr~ log10(Tot_dea1M_pop)+log10(Internet_users),
                   family = "binomial", data =data)
summary(glm_deaths11)
summary(aov(glm_deaths11))
odds.ratio(glm_deaths11)

PseudoR2(glm_deaths11)
check_model(glm_deaths11)

tiff(compression = "lzw",width = 18, height = 15, units = "cm", res = 600)
check_model(glm_deaths11)
dev.off()

performance(glm_deaths11)
performance_accuracy(glm_deaths11, method = "boot", k = 60, n = 1000)
check_collinearity(glm_deaths11)
performance_mse(glm_deaths11)
check_outliers(glm_deaths11)



# graph of probability of interest versus total deathes 
fig333 <- ggplot(data, aes(x = Tot_dea1M_pop, y = Covid_meme_occurr))+
  theme_bw()+
  geom_point(size = 4, shape = 19, alpha = 0.3)+
  scale_x_log10(labels = function(x) format(x, scientific = FALSE))+
  geom_smooth(method = 'glm', fill = "#bf987d",
              col = "#98623c", method.args = list(family = "binomial"))+
  labs(x = "Total deaths per million", y ="Probability of interest in the Covid memes")+
  theme(axis.text = element_text(color = "black", size = 14),
        axis.title =element_text(color = "black", size = 14))
fig333 

ggsave(fig333, filename = "fig333.tiff", width = 14, height = 12, units = "cm", dpi = 600)



# logistic regression model of probability of interest versus total cases
glm_cases11 <- glm(Covid_meme_occurr~ log10(T_cas1M_pop)+log10(Internet_users),
                  family = "binomial", data =data)
summary(glm_cases11)
summary(aov(glm_cases11))
odds.ratio(glm_cases11)
PseudoR2(glm_cases11)
check_model(glm_cases11)

tiff(compression = "lzw",width = 18, height = 15, units = "cm", res = 600)
check_model(glm_cases11)
dev.off()

performance(glm_cases11)
performance_accuracy(glm_cases11, method = "boot", k = 60, n = 1000)
check_collinearity(glm_cases11)
performance_mse(glm_cases11)
check_outliers(glm_cases11)
check_normality(glm_cases11)




# graph of probability of interest versus total cases

fig444 <- ggplot(data, aes(x = T_cas1M_pop, y = Covid_meme_occurr))+
  theme_bw()+
  geom_point(size = 4, shape = 19, alpha = 0.3)+
  scale_x_log10(labels = function(x) format(x, scientific = FALSE))+
  geom_smooth(method = 'glm', fill = "#bf987d",
              col = "#98623c", method.args = list(family = "binomial"))+
  labs(x = "Total cases per million", y ="Probability of interest in the Covid memes")+
  theme(axis.text = element_text(color = "black", size = 14),
        axis.title =element_text(color = "black", size = 14))
fig444 
ggsave(fig444, filename = "fig444.tiff", width = 14, height = 12, units = "cm", dpi = 600)


### ----- ANALYSIS OF TRENDS ---------------------

trends <- read_excel("memes_country_data.xlsx", sheet = "trends")
trends$String <- factor(trends$String, ordered = T, levels =
                          c("Coronavirus meme", "Covid meme", "Covid19 meme",
                            "Coronavirus death", "Coronavirus",
                            "Meme", "Death"))
trends$Interest <- as.numeric(trends$Interest)
View(trends)
str(trends)
trends$Week <- as.Date(trends$Week)

# embracing lockdown time
k <- trends$Week[[229]]
l <- trends$Week[[240]]

#plot
p100 <- ggplot(data = trends, aes(x = Week,
                                  y = Interest))+
  theme_bw()+
  geom_rect(xmin=k, xmax=l, 
            ymin=-Inf, ymax=Inf, fill= "#6faef4",
            col = "#6faef4", alpha=0.006)+
  geom_line(col = "#98623c")+
  facet_wrap(.~String, nrow = 7)+
  scale_x_date(labels = date_format("%Y-%m"), date_breaks = "2 month")+
  labs(x = "Date (year-month)", y = "Interest (Google Trends Index)")+
  theme(axis.title = element_text(size = 14),
        strip.text = element_text(size = 12))

p100

ggsave(p100, filename = "fig5_facet1.tiff", width = 12, height = 21, units = "cm", dpi = 600)

#### Covid statistics trends ------

covid <- read_excel("memes_country_data.xlsx", sheet = "covid_data")

str(covid)
covid$Week <- as.Date(covid$Week)
p200 <- ggplot(data = covid, aes(x = Week,
                                 y =N ))+
  theme_bw()+
  geom_rect(xmin=k, xmax=l, 
            ymin=-Inf, ymax=Inf, fill= "#6faef4",
            col = "#6faef4", alpha=0.006)+
  geom_line(col = "#98623c")+
  scale_y_continuous(labels = function(x) format(x, scientific = FALSE))+
  facet_wrap(.~Variable, nrow = 3, scales = "free")+
  scale_x_date(labels = date_format("%Y-%m"), 
               date_breaks = "2 month")+
  labs(x = "Date (year-month)", y = "Number")+
  theme(axis.title = element_text(size = 14),
        strip.text = element_text(size = 12))
p200
ggsave(p200, filename = "fig6_facet.tiff", width = 12, height = 10.6, units = "cm", dpi = 600)


##------VISUALIZING CORRELATIONS AMONG VARIABLES------

correl <- read_excel("memes_country_data.xlsx", sheet = "Graph_corr")
cor_mat <- cor(correl)
# Google Trends interest in coronavirus memes vs "coronavirus"
cor.test(correl$CRM, correl$C)
# Google Trends interest in coronavirus memes vs "coronavirus deaths"
cor.test(correl$CRM, correl$CD)
# Google Trends interest in coronavirus memes vs "death"
cor.test(correl$CRM, correl$D)
# Google Trends interest in coronavirus memes vs coronavirus SAR-CoV-2 new cases (CNC)
cor.test(correl$CRM, correl$CNC)
# Google Trends interest in coronavirus memes vs coronavirus SAR-CoV-2 new deaths (CND)
cor.test(correl$CRM, correl$CND)
# Google Trends interest in covid memes vs coronavirus SAR-CoV-2 new cases (CNC)
cor.test(correl$CVM, correl$CNC)
# Google Trends interest in covid memes vs coronavirus SAR-CoV-2 new deaths (CND)
cor.test(correl$CVM, correl$CND)
# Google Trends interest in coronavirus memes vs number of webpages with covid/covid19/coronavirus memes
cor.test(correl$CRM,correl$GS)
# Google Trends interest in covid memes vs number of webpages with covid/covid19/coronavirus memes
cor.test(correl$CVM, correl$GS)
# Google Trends interest in covid19 memes vs number of webpages with covid/covid19/coronavirus memes
cor.test(correl$C19, correl$GS)
# Number of webpages with covid/covid19/coronavirus memes vs Covid19 new cases
cor.test(correl$GS, correl$CNC)
# Number of webpages with covid/covid19/coronavirus memes vs Covid19 new deaths
cor.test(correl$GS, correl$CND)


cor_mat
dim(correl)
str(correl)
#network graph
qgraph::qgraph(cor_mat ,theme  ="TeamFortress", graph = "cor",
               posCol = "#98623c", negCol = "steelblue",
               vTrans = 250, minimum = "sig", 
               sampleSize = dim(correl)[1],
               edge.labels = TRUE, edge.label.cex = 1.5,
               edge.label.color = "steelblue",
               filetype = "tiff")

# insert "filetype = "tiff"" if want to save the graph

### ----------- TEXT AND SENTIMENT ANALYSIS -----------------


#---- 1. Analysis for coronavirus memes-------------

#Insert your own path to folder with files

filePath <- "C:\\Users\\pskorka\\Documents\\Archiwum_May_2020\\Dokumenty\\Maszynopisy\\IJERPH\\supplemental\\coronavirus_memes_cleaned.txt"
corona_memes <- readLines(filePath)
# Load the data as a corpus
corona_memes_1 <- Corpus(VectorSource(corona_memes))

#Inspect the content of the document
inspect(corona_memes_1)
#Text transformation Transformation is performed using tm_map() function to replace, for example, special
#characters from the text.
#Replacing ?/?, ?@? and ?|? with space:
toSpace <- content_transformer(function (x , pattern ) gsub(pattern, " ", x))
corona_memes_1 <- tm_map(corona_memes_1, toSpace, "/")
corona_memes_1 <- tm_map(corona_memes_1, toSpace, "\\|")

#Cleaning the text the tm_map() function is used to remove unnecessary white space, to convert the text to
#lower case, to remove common stopwords 
# Convert the text to lower case
corona_memes_1 <- tm_map(corona_memes_1, content_transformer(tolower))

# Remove numbers
corona_memes_1 <- tm_map(corona_memes_1, removeNumbers)


# Remove english common stopwords

corona_memes_1 <- tm_map(corona_memes_1, removeWords, stopwords("english"))

# Remove your own stop word, use the specified above vector words_rem
words_rem <- c("can", "like","just" ,"now", "do", "on", "would", "will",
               "and", "the", "for", "to", "its", "with", "this", "that",
               "too", "may")
corona_memes_1 <- tm_map(corona_memes_1, removeWords, words_rem)

# Remove punctuations
corona_memes_1 <- tm_map(corona_memes_1, removePunctuation)

# Eliminate extra white spaces
corona_memes_1 <- tm_map(corona_memes_1, stripWhitespace)

# Build a term-document matrix
corona_memes_1_dtm <- TermDocumentMatrix(corona_memes_1)
dtm_corona_memes_1 <- as.matrix(corona_memes_1_dtm)
# Sort by descearing value of frequency
dtm_v_corona_memes_1 <- sort(rowSums(dtm_corona_memes_1),decreasing=TRUE)
dtm_d_corona_memes_1 <- data.frame(word = names(dtm_v_corona_memes_1),freq=dtm_v_corona_memes_1)


head(dtm_d_corona_memes_1, 25)
dim(dtm_d_corona_memes_1)[1] #number of words in text memes

#Generate the Word cloud The importance of words can be illustrated as a word cloud as follow :
set.seed(1234)

tiff(file="memes_cloud.tiff",
     width=6, height=6, units="in", res=300)

wordcloud(words = dtm_d_corona_memes_1$word, freq = dtm_d_corona_memes_1$freq, min.freq = 2,
          max.words=150, random.order=FALSE, rot.per=0.5,
          colors= c("#bf987d", "steelblue", "red"))

dev.off()


# The frequency table of words
#ordering 
dtm_d_corona_memes_1$word <- factor(dtm_d_corona_memes_1$word, levels = dtm_d_corona_memes_1$word[order(dtm_d_corona_memes_1$freq)]) 
length(dtm_d_corona_memes_1$word)
#barplot
barplot1 <- ggplot(data = dtm_d_corona_memes_1[1:15,], aes(x = word, y = freq))+
  theme_bw()+
  geom_bar(stat ="identity", fill = "#bf987d")+
  coord_flip()+
  theme(axis.title = element_text(size = 14),
        axis.text = element_text(size = 14))+
  ylim(c(0,60))+
  labs(x = "Word", y = "Frequency")
barplot1

ggsave(barplot1, filename = "words_corona_memes.tiff", width = 12, height = 10, units = "cm", dpi = 600)


#---- 2. Sentiment analysis coronavirus meme (based on bing dictionary)---

positive_senti <- get_sentiments("bing") %>%
  filter(sentiment == "positive")

dtm_d_corona_memes_1 %>%
  semi_join(positive_senti) %>%
  count(word, sort = TRUE)
bing <- get_sentiments("bing")

counting_words_corona <- dtm_d_corona_memes_1 %>%
  inner_join(bing) %>%
  count(word, sentiment, sort = TRUE)
head(counting_words_corona)



#summary of positive and negative words
sent_corona <- dtm_d_corona_memes_1 %>%
  inner_join(bing) %>%
  count(word, sentiment, sort = T)%>%
  acast(word ~ sentiment)
colSums(sent_corona, na.rm =T)


### Non-coronavirus memes ----------------

# Set your own flie path from your computer
filePath1 <- "C:\\Users\\pskorka\\Documents\\Archiwum_May_2020\\Dokumenty\\Maszynopisy\\IJERPH\\supplemental\\non_coronavirus_memes_cleaned.txt"

noncorona_memes <- readLines(filePath1)

# Load the data as a corpus
noncorona_memes_1 <- Corpus(VectorSource(noncorona_memes))

#Inspect the content of the document
inspect(noncorona_memes_1)

#Replacing ?/?, ?@? and ?|? with space:
toSpace <- content_transformer(function (x , pattern ) gsub(pattern, " ", x))
noncorona_memes_1 <- tm_map(noncorona_memes_1, toSpace, "/")
noncorona_memes_1 <- tm_map(noncorona_memes_1, toSpace, "\\|")

# Convert the text to lower case
noncorona_memes_1 <- tm_map(noncorona_memes_1, content_transformer(tolower))

# Remove numbers
noncorona_memes_1 <- tm_map(noncorona_memes_1, removeNumbers)


# Remove english common stopwords

noncorona_memes_1 <- tm_map(noncorona_memes_1, removeWords, stopwords("english"))

# Remove your own stop word, use the specified above vector words_rem
words_rem <- c("can", "like","just" ,"now", "do", "on", "would", "will",
               "and", "the", "for", "to", "its", "with", "this", "that",
               "too", "may", "get", "gets")
noncorona_memes_1 <- tm_map(noncorona_memes_1, removeWords, words_rem)

# Remove punctuations
noncorona_memes_1 <- tm_map(noncorona_memes_1, removePunctuation)

# Eliminate extra white spaces
noncorona_memes_1 <- tm_map(noncorona_memes_1, stripWhitespace)


#Build a term-document matrix 

noncorona_memes_1_dtm <- TermDocumentMatrix(noncorona_memes_1)
dtm_noncorona_memes_1 <- as.matrix(noncorona_memes_1_dtm)
# Sort by descearing value of frequency
dtm_v_noncorona_memes_1 <- sort(rowSums(dtm_noncorona_memes_1),decreasing=TRUE)
dtm_d_noncorona_memes_1 <- data.frame(word = names(dtm_v_noncorona_memes_1),freq=dtm_v_noncorona_memes_1)

# Display the top 25 most frequent words

head(dtm_d_noncorona_memes_1, 25)
dim(dtm_d_noncorona_memes_1)[1] #number of words in text noncoronavirus memes


#Generate the Word cloud The importance of words can be illustrated as a word cloud as follow :
set.seed(1234)

tiff(file="noncorona_cloud.tiff",
     width=6, height=6, units="in", res=300)

wordcloud(words = dtm_d_noncorona_memes_1$word, freq = dtm_d_noncorona_memes_1$freq, min.freq = 2,
            max.words=150, random.order=FALSE, rot.per=0.5,
            colors= c("#bf987d", "steelblue", "red"))
dev.off()


# The frequency table of words
#ordering 
dtm_d_noncorona_memes_1$word <- factor(dtm_d_noncorona_memes_1$word, levels = dtm_d_noncorona_memes_1$word[order(dtm_d_noncorona_memes_1$freq)]) 

#barplot
barplot2 <- ggplot(data = dtm_d_noncorona_memes_1[1:15,], aes(x = word, y = freq))+
  theme_bw()+
  geom_bar(stat ="identity", fill = "#bf987d")+
  coord_flip()+
  theme(axis.title = element_text(size = 14),
        axis.text = element_text(size = 14))+
  ylim(c(0,60))+
  labs(x = "Word", y = "Frequency")
barplot2

ggsave(barplot2, filename = "words_noncorona_memes.tiff", width = 12, height = 10, units = "cm", dpi = 600)


#---- 4. Sentiment analysis noncoronavirus meme (based on bing dictionary)---

positive_senti <- get_sentiments("bing") %>%
  filter(sentiment == "positive")

dtm_d_noncorona_memes_1 %>%
  semi_join(positive_senti) %>%
  count(word, sort = TRUE)
bing <- get_sentiments("bing")
dim(dtm_d_noncorona_memes_1)
counting_words_noncorona <- dtm_d_noncorona_memes_1 %>%
  inner_join(bing) %>%
  count(word, sentiment, sort = TRUE)
head(counting_words_noncorona)


#summary of positive and negative words
sent_noncorona <- dtm_d_noncorona_memes_1 %>%
  inner_join(bing) %>%
  count(word, sentiment, sort = T)%>%
  acast(word ~ sentiment)
colSums(sent_noncorona, na.rm =T)

## IMAGE CONTENT ANALYSIS

image_content <- read_excel("Meme_text_data.xlsx", 
                            sheet = "image_content")
table1 <- table(image_content$Memes, image_content$Object)
plot(table1)
chisq.test(table1)
# re-order levels
reorder_size <- function(x) {
  factor(x, levels = names(sort(table(x), decreasing = TRUE)))
}

corona_images <- image_content %>%
  filter(Object != "Both") 
str(corona_images)


pp <-ggplot(corona_images, aes(x = reorder_size(Content), fill = Memes,
                               col = Memes)) +
  theme_bw()+
  scale_color_manual(values = c("#bf987d","#6faef4"))+
  scale_fill_manual(values = c("#bf987d","#6faef4"))+
  geom_bar(aes(y = (..count..)/sum(..count..))) +
  xlab("Main content") +
  scale_y_continuous(labels = scales::percent, name = "Proportion of images") +
  facet_grid(Memes ~ Object) +
  theme(axis.text.x = element_text(angle = 90, hjust = 1, 
                                   vjust = 0.5, size = 10,
                                   color = "black"),
        axis.title = element_text(size = 14),
        legend.title = element_text(size =12),
        legend.text = element_text(size =11),
        axis.text.y = element_text(size =12),
        strip.text = element_text(size = 12))

pp

ggsave(pp, filename = "meme_image_content.tiff", units = "cm",
       dpi = 600, height = 16, width = 28)


## proportion of emotional words
prop_emotional <- data.frame(matrix(ncol = 2, c(125,900,101,740)))
chisq.test(prop_emotional)

prop_positive <- data.frame(matrix(ncol = 2, c(46,79, 42, 56)))
chisq.test(prop_positive)



## Cramers V

# Cramers for human objects

summa <- corona_images %>%
  group_by(Memes, Object, Content) %>%
  summarise(weg = n())

summa_human <- summa %>%
  filter(Object == "Human") %>%
  spread(key = "Memes", value = "weg")

icc_human <- summa_human[,c(3:4)]

#converting NA into zeros
icc_human[is.na(icc_human)] <- 0

#Cramer V coefficient

cramer(Coronavirus ~ `Non coronavirus`, data = icc_human,
       ci = T, ci.lvl = .95, n = 100,
       bias.correct = T )
library(lsr)

#Spearmna correlation - not valid!
#cor.test(icc_human$Coronavirus, icc_human$`Non coronavirus`, method = "s")

  
# Cramver for non-human objects

summa_nonhuman <- summa %>%
  filter(Object != "Human") %>%
  spread(key = "Memes", value = "weg")

icc_nonhuman <- summa_nonhuman[,c(3:4)]
#substituting NA with zeros
icc_nonhuman[is.na(icc_nonhuman)] <- 0

#Cramer V 

cramer(Coronavirus ~ `Non coronavirus`, data = icc_nonhuman,
       ci = T, ci.lvl = .95, n = 100,
       bias.correct = T )


#cor.test(icc_nonhuman$Coronavirus, icc_nonhuman$`Non coronavirus`, method = "s")

# text aggreement for text content
dtm_d_corona_memes_1
dim(dtm_d_corona_memes_1)
dtm_d_noncorona_memes_1
joined <- merge(x = dtm_d_corona_memes_1,
                y = dtm_d_noncorona_memes_1, by = "word", all = TRUE)
dim(joined)
View(joined)
head(joined, 15)
joined_icc <- joined[,c(2,3)]
joined_icc[is.na(joined_icc)] <- 0


#Cramer V coefficient all words coronavirus memes vs non coronavirus memes

cramer(freq.x ~ freq.y, data = joined_icc,
       ci = T, ci.lvl = .95, n = 100,
       bias.correct = T )


# Analysis repeated for 30 the most common words
dtm_d_corona_memes_1
dim(dtm_d_noncorona_memes_1)
dtm_d_noncorona_memes_1
joined_r<- merge(x = dtm_d_corona_memes_1[c(1:30),],
                 y = dtm_d_noncorona_memes_1[c(1:30),], by = "word", all = TRUE)
head(joined_r, 15)
joined_icc_r <- joined_r[,c(2,3)]
joined_icc_r[is.na(joined_icc_r)] <- 0

#Cramer V coefficient
cramer(freq.x ~ freq.y, data = joined_icc_r,
       ci = T, ci.lvl = .95, n = 100,
       bias.correct = T )

# Spearman correlation - not valid!
#cor.test(joined_icc_r$freq.x, joined_icc_r$freq.x,method = "s")




### --- MEME FUNNINESS -----------


questionnaire <- read_excel("Results_questionnaire.xlsx", 
                            sheet = "together")
#summary stats
questionnaire%>%
  group_by(Country)%>% 
  summarise(nnn = n())
str(questionnaire)


questionnaire_long <- read_excel("Results_questionnaire.xlsx", 
                                 sheet = "long_format")
questionnaire_long <- questionnaire_long %>% filter(Gender != "NA")

questionnaire_long$Gender <- factor(questionnaire_long$Gender)
questionnaire_long$test <- factor(questionnaire_long$test)
questionnaire_long$ID <- factor(questionnaire_long$ID)
questionnaire_long$Meme <- factor(questionnaire_long$Meme)
questionnaire_long$Variable <- factor(questionnaire_long$variable)
questionnaire_long$Geogr <- factor(questionnaire_long$Geogr)
questionnaire_long$Age <- scale(questionnaire_long$Age)
str(questionnaire_long)
questionnaire_long$ValueO <- factor(questionnaire_long$value,
                                       ordered = T, 
                                       levels = c("1", '2', "3", "4", '5'))

# plotting percentage of responses for different scores in the questionnaire
library(scales)

hist_scores <- ggplot(questionnaire_long, aes(x = ValueO)) +
  theme_bw()+
geom_bar(aes(y = (((..count..)/sum(..count..)))*100),fill = "#6faef4",
         col = "steelblue",  alpha = 0.8,width = .995) + 
  theme(axis.title =  element_text(size = 16, colour = "black"),
        axis.text = element_text(size = 14, colour = "black"))+
  labs(x = "Questionnaire scores", y = "Percentage of responses (%)")+
  scale_y_continuous()+
  facet_grid(Meme ~ .)+
  theme(legend.title = element_blank(),
        legend.text = element_text(size = 12))+
  theme(strip.text = element_text(size = 12, face = "bold"))
hist_scores
  
ggsave(hist_scores, filename = "hist_scores.tiff", dpi= 600, units = "cm",
       height = 18, width = 13) 


str(questionnaire_long)
library('ordinal')
# Cumulative Link Mixed Models with one or more random effects
fm1 <- clmm(ValueO ~ Meme + Age + Gender + Age:Gender + 
              (1|ID:test) +(1|test), data=questionnaire_long, Hess = T)
fm1_null <- clmm(ValueO ~ 1 + (1|ID:test) +(1|test), data=questionnaire_long, Hess = T)
summary(fm1)
tidy(fm1)
# conf interval for odd ratios in fm1
round(exp(confint(fm1)), 3)
# odd ratios
round(exp(coefficients(fm1)),3)
glance(fm1)
# McFadden r2
rcompanion::nagelkerke(fm1, fm1_null)
str(tmp)

#questionnaire_long$fitted <- fitted(fm1)
#questionnaire_long$predicted <- exp(questionnaire_long$fitted)/(1 + exp(questionnaire_long$fitted))
#plot(predicted~Meme, data=questionnaire_long)
tmp <- ref_grid(fm1, mode = "lin")
tmp
str(questionnaire_long)
emmeans(fm1, "Meme", mode = "mean.class")


# building the graph of the effect of meme

eff <- ggpredict(fm1, terms = "Meme")
plot(eff)
View(eff)

questionnaire_response <- list(
  '1'="Score = 1",
  '2'="Score = 2",
  '3'="Score = 3",
  '4'="Score = 4",
  '5'="Score = 5"
)

q_labeller <- function(variable,value){
  return(questionnaire_response[value])
}

last <- ggplot(eff, aes(x = x, y = predicted, col = x))+
  theme_bw()+
  geom_point(size = 4)+
  geom_errorbar(aes(x = x, ymin = conf.low, ymax = conf.high),
                width=0.3, size = 1)+
  theme(axis.title =  element_text(size = 16, colour = "black"),
        axis.text = element_text(size = 14, colour = "black"))+
  labs(x = "Meme type", y = "Probability of the score")+
  scale_color_manual(values = c("#bf987d","#6faef4", "#2a623d"),
                     name = "Meme type")+
  facet_wrap(~response.level,nrow = 1,
             labeller = q_labeller)+
  theme(legend.title = element_blank(),
        legend.text = element_text(size = 12))+
  theme(strip.text = element_text(size = 12, face = "bold"))+
  theme(axis.text.x = element_text(angle = 90, vjust = 0.5, hjust=1,
                                   size = 10))+
  scale_y_continuous(breaks = c(0,0.25, 0.5, 0.75, 1), limits = c(0,1.01))
last
ggsave(last, filename = "last.tiff", dpi= 600, units = "cm",
       height = 15, width = 20) 

#plotting the interaction between age and gender
ggpredictions_ols1 = ggpredict(fm1, terms = c( "Age","Gender"))

#use labbeller from next grapghs
age_gender <- plot(ggpredictions_ols1, show.title = F)+
  theme_bw()+
  theme(axis.title =  element_text(size = 16, colour = "black"),
        axis.text = element_text(size = 14, colour = "black"))+
  labs(x = "Age (scaled)", y = "Probability of the score")+
  facet_wrap(~response.level,nrow = 1,
             labeller = q_labeller)+
  theme(legend.title = element_blank(),
        legend.text = element_text(size = 12))+
  theme(strip.text = element_text(size = 12, face = "bold"))+
  theme(axis.text.x = element_text(angle = 90, vjust = 0.5, hjust=1,
                                   size = 10))+
  scale_y_continuous(breaks = c(0,0.25, 0.5, 0.75, 1), limits = c(0,1.01))

age_gender 

ggsave(age_gender, filename = "age_x_gender.tiff", dpi= 600, units = "cm",
       height = 15, width = 18)





###---- Analysis for subset of Polish participants only

subset_poland <- questionnaire_long %>%
  filter(Country == "Poland")
View(subset_poland)

# Cumulative Link Mixed Models with one or more random effects
fm1p <- clmm(ValueO ~ Meme + Age + Gender + Age:Gender + 
              (1|ID:test) +(1|test), data=subset_poland, Hess = T)
fm1p_nullp <- clmm(ValueO ~ 1 + (1|ID:test) +(1|test), data=subset_poland, Hess = T)
summary(fm1p)
tidy(fm1p)
# conf interval for odd ratios in fm1
round(exp(confint(fm1p)), 3)
# odd ratios
round(exp(coefficients(fm1p)),3)
glance(fm1p)
# McFadden r2
rcompanion::nagelkerke(fm1p, fm1p_nullp)
str(tmp)


#questionnaire_long$fitted <- fitted(fm1)
#questionnaire_long$predicted <- exp(questionnaire_long$fitted)/(1 + exp(questionnaire_long$fitted))
#plot(predicted~Meme, data=questionnaire_long)
# building the graph of the effect of meme

eff_poland <- ggpredict(fm1p, terms = "Meme")
plot(eff_poland)
View(eff_poland)

questionnaire_response <- list(
  '1'="Score = 1",
  '2'="Score = 2",
  '3'="Score = 3",
  '4'="Score = 4",
  '5'="Score = 5"
)

q_labeller <- function(variable,value){
  return(questionnaire_response[value])
}

last_poland <- ggplot(eff_poland, aes(x = x, y = predicted, col = x))+
  theme_bw()+
  geom_point(size = 4)+
  geom_errorbar(aes(x = x, ymin = conf.low, ymax = conf.high),
                width=0.3, size = 1)+
  theme(axis.title =  element_text(size = 16, colour = "black"),
        axis.text = element_text(size = 14, colour = "black"))+
  labs(x = "Meme type", y = "Probability of the score")+
  scale_color_manual(values = c("#bf987d","#6faef4", "#2a623d"),
                     name = "Meme type")+
  facet_wrap(~response.level,nrow = 1,
             labeller = q_labeller)+
  theme(legend.title = element_blank(),
        legend.text = element_text(size = 12))+
  theme(strip.text = element_text(size = 12, face = "bold"))+
  theme(axis.text.x = element_text(angle = 90, vjust = 0.5, hjust=1,
                                   size = 10))+
  scale_y_continuous(breaks = c(0,0.25, 0.5, 0.75, 1), limits = c(0,1.01))
last_poland
ggsave(last_poland, filename = "last_poland.tiff", dpi= 600, units = "cm",
       height = 15, width = 20) 

#plotting the interaction between age and gender
ggpredictions_ols1_p = ggpredict(fm1p, terms = c( "Age","Gender"))

#use labbeller from next grapghs
age_gender_poland <- plot(ggpredictions_ols1_p, show.title = F)+
  theme_bw()+
  theme(axis.title =  element_text(size = 16, colour = "black"),
        axis.text = element_text(size = 14, colour = "black"))+
  labs(x = "Age (scaled)", y = "Probability of the score")+
  facet_wrap(~response.level,nrow = 1,
             labeller = q_labeller)+
  theme(legend.title = element_blank(),
        legend.text = element_text(size = 12))+
  theme(strip.text = element_text(size = 12, face = "bold"))+
  theme(axis.text.x = element_text(angle = 90, vjust = 0.5, hjust=1,
                                   size = 10))+
  scale_y_continuous(breaks = c(0,0.25, 0.5, 0.75, 1), limits = c(0,1.01))

age_gender_poland 

ggsave(age_gender_poland, filename = "age_x_gender_poland.tiff", dpi= 600, units = "cm",
       height = 15, width = 18)
